# AnnotatedImage {: #metanno.ui.AnnotatedImage }

::: metanno.ui.AnnotatedImage
    options:
        heading_level: 2
        show_bases: false
        show_source: false
        only_class_level: true
